@@ -78,18 +78,22 @@ class ImageGenerator(
             # ),
         ).to(self.device)
 
+        self.supported_loss_types = [
+            "cosine_similarity",
+            "spherical_distance",
+        ]
+
     def add_noise(
         self,
         img_batch: torch.Tensor,
-        up_noise: float = 0.11,
-        p: float = 1,
+        noise_factor: float = 0.11,
     ) -> torch.Tensor:
         # noise = torch.rand((img_batch.shape[0], 1, 1, 1)).to(self.device)
         # noise *= torch.randn_like(img_batch, requires_grad=False)
-        noise = up_noise * torch.rand((img_batch.shape[0], 1, 1, 1)).to(
+        noise = noise_factor * torch.rand((img_batch.shape[0], 1, 1, 1)).to(
             self.device) * torch.randn_like(img_batch, requires_grad=False)
 
-        # batch_mask = (torch.rand((img_batch.shape[0])) <= p).to(self.device)
+        # batch_mask = (torch.rand((img_batch.shape[0])) <= noise_factor).to(self.device)
         # noise *= batch_mask[:, None, None, None]
 
         img_batch = img_batch + noise
@@ -104,6 +108,8 @@ class ImageGenerator(
         target_img_height: int = None,
         crop_scaler: int = 1,
         num_crops=64,
+        noise_factor: float = 0.11,
+        pad_downscale: int = 3,
     ):
         """
         Augments a batch of images using random crops, affine
@@ -124,9 +130,8 @@ class ImageGenerator(
         if target_img_width is None:
             target_img_width = img_batch.shape[2]
 
-        pad_scale = 3
-        x_pad_size = target_img_width // pad_scale
-        y_pad_size = target_img_height // pad_scale
+        x_pad_size = target_img_width // pad_downscale
+        y_pad_size = target_img_height // pad_downscale
         img_batch = torch.nn.functional.pad(
             img_batch,
             (
@@ -159,13 +164,13 @@ class ImageGenerator(
 
             offsetx = torch.randint(
                 0,
-                int(target_img_width + target_img_width * 2 / pad_scale -
+                int(target_img_width + target_img_width * 2 / pad_downscale -
                     crop_size),
                 (),
             )
             offsety = torch.randint(
                 0,
-                int(target_img_height + target_img_height * 2 / pad_scale -
+                int(target_img_height + target_img_height * 2 / pad_downscale -
                     crop_size),
                 (),
             )
@@ -193,7 +198,10 @@ class ImageGenerator(
         #     img_list.append(self.aug_transform(img_batch))
         # img_batch = torch.cat(img_list)
 
-        img_batch = self.add_noise(img_batch, )
+        img_batch = self.add_noise(
+            img_batch,
+            noise_factor=noise_factor,
+        )
 
         # from PIL import Image
         # import numpy as np
@@ -301,15 +309,6 @@ class ImageGenerator(
 
         return loss
 
-    @abc.abstractmethod
-    def generate_from_prompt(
-        self,
-        *args,
-        **kwargs,
-    ) -> Tuple[List[PIL.Image.Image], List[torch.Tensor]]:
-        raise NotImplementedError(
-            '`generate_from_prompt` method must be defined by the user.')
-
     def load_img(
         self,
         img_path: str,
@@ -333,6 +332,15 @@ class ImageGenerator(
 
         return img_tensor
 
+    @abc.abstractmethod
+    def generate_from_prompt(
+        self,
+        *args,
+        **kwargs,
+    ) -> Tuple[List[PIL.Image.Image], List[torch.Tensor]]:
+        raise NotImplementedError(
+            '`generate_from_prompt` method must be defined by the user.')
+
 
 if __name__ == "__main__":
     prompt = "The image of a rainy landscape"
