@@ -6,6 +6,7 @@ from typing import *
 import torch
 import torchvision
 import PIL
+from PIL import Image
 import numpy as np
 from bigotis.modeling_utils import ImageGenerator
 
@@ -219,14 +220,22 @@ class Aphantasia(ImageGenerator):
 
         return fft_img
 
-    def get_img_rec_from_latents(
+    def get_img_size_from_latents(
+        self,
+        latents,
+    ):
+        height = latents.shape[2]
+        width = (latents.shape[3] - 1) * 2
+
+        return height, width
+
+    def get_img_from_latents(
         self,
         latents,
     ):
         shift = None
 
-        height = latents.shape[2]
-        width = (latents.shape[3] - 1) * 2
+        height, width = self.get_img_size_from_latents(latents, )
 
         #NOTE: generat all possible freqs for the input image size
         img_freqs = self.compute_2d_img_freqs(
@@ -338,7 +347,7 @@ class Aphantasia(ImageGenerator):
         for step in range(num_steps):
             loss = 0
 
-            initial_img = self.get_img_rec_from_latents(latents=fft_img, )
+            initial_img = self.get_img_from_latents(latents=fft_img, )
 
             x_rec_stacked = self.augment(
                 img_batch=initial_img,
@@ -356,7 +365,7 @@ class Aphantasia(ImageGenerator):
             optimizer.step()
 
             with torch.no_grad():
-                rec_img = self.get_img_rec_from_latents(latents=fft_img, )
+                rec_img = self.get_img_from_latents(latents=fft_img, )
                 x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(
                     rec_img[0], )
 
@@ -377,19 +386,19 @@ class Aphantasia(ImageGenerator):
 
     def interpolate(
         self,
-        fft_img_list: List,
+        latents_list: List,
         duration_list: List[float],
-        height: int,
-        width: int,
+        height: int = None,
+        width: int = None,
         **kwargs,
     ):
         """
         Returns a list of PIL images corresponding to the 
         generations produced by interpolating the values
-        from `fft_img_list`.
+        from `latents_list`.
 
         Args:
-            fft_img_list (List[torch.Tensor]): list of fft tensors
+            latents_list (List[torch.Tensor]): list of fft tensors
                 that encode image generations.
             duration_list (List[float]): list with the duration of
                 the interpolation between each consecutive tensor. 
@@ -403,27 +412,15 @@ class Aphantasia(ImageGenerator):
         Returns:
             List[PIL.Image.Image]: list of the resulting generated images.
         """
-        img_freqs = self.compute_2d_img_freqs(
-            height=height,
-            width=width,
-        )
-
-        fft_img = self.get_random_latents(
-            height,
-            width,
-            batch_size=1,
-            std=0.01,
-        )
-
-        scale = self.get_scale_from_img_freqs(
-            img_freqs=img_freqs,
-            decay_power=1,
-        )
-        scale = scale.to(self.device)
+        fft_img_list = latents_list
 
         gen_img_list = []
         fps = 25
 
+        if height is None or width is None:
+            logging.info("Inferring image size")
+            height, width = self.get_img_size_from_latents(latents_list[0], )
+
         for idx, (fft_img,
                   duration) in enumerate(zip(fft_img_list, duration_list)):
             num_steps = int(duration * fps)
@@ -433,15 +430,8 @@ class Aphantasia(ImageGenerator):
             for step in range(num_steps):
                 weight = math.sin(1.5708 * step / num_steps)**2
                 fft_img_interp = weight * fft_img_2 + (1 - weight) * fft_img_1
-                img = self.fft_to_rgb(
-                    fft_img=fft_img_interp,
-                    scale=scale,
-                    height=height,
-                    width=width,
-                    shift=None,
-                    contrast=1.0,
-                    decorrelate=True,
-                )
+                img = self.get_img_from_latents(latents=fft_img_interp, )
+
                 img = img.detach().cpu().numpy()[0]
                 img = np.transpose(np.array(img)[:, :, :], (1, 2, 0))
                 img = np.clip(img * 255, 0, 255).astype(np.uint8)
@@ -449,6 +439,8 @@ class Aphantasia(ImageGenerator):
 
                 gen_img_list.append(pil_img)
 
+                torch.cuda.empty_cache()
+
         return gen_img_list
 
 
